==> func_adl_servicex_xaodr22-2.1.1.22.2.107b2-py3-none-any.whl: func_adl_servicex_xaodr22/xAOD/cmxjethits_v1.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
from enum import Enum
import func_adl_servicex_xaodr22

_method_map = {
    'hitsVec0': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'hitsVec0',
        'return_type_element': 'unsigned short',
        'return_type_collection': 'const vector<unsigned int>',
    },
    'hitsVec1': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'hitsVec1',
        'return_type_element': 'unsigned short',
        'return_type_collection': 'const vector<unsigned int>',
    },
    'errorVec0': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'errorVec0',
        'return_type_element': 'unsigned short',
        'return_type_collection': 'const vector<unsigned int>',
    },
    'errorVec1': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'errorVec1',
        'return_type_element': 'unsigned short',
        'return_type_collection': 'const vector<unsigned int>',
    },
    'hits0': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'hits0',
        'return_type': 'unsigned int',
    },
    'hits1': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'hits1',
        'return_type': 'unsigned int',
    },
    'error0': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'error0',
        'return_type': 'unsigned int',
    },
    'error1': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'error1',
        'return_type': 'unsigned int',
    },
    'index': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'index',
        'return_type': 'int',
    },
    'usingPrivateStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'usingPrivateStore',
        'return_type': 'bool',
    },
    'usingStandaloneStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'usingStandaloneStore',
        'return_type': 'bool',
    },
    'hasStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'hasStore',
        'return_type': 'bool',
    },
    'hasNonConstStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'hasNonConstStore',
        'return_type': 'bool',
    },
    'clearDecorations': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'clearDecorations',
        'return_type': 'bool',
    },
    'trackIndices': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'trackIndices',
        'return_type': 'bool',
    },
    'auxdataConst': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'auxdataConst',
        'return_type': 'U',
    },
    'isAvailable': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'isAvailable',
        'return_type': 'bool',
    },
}

_enum_map = {      
}

T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])

        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTrigL1Calo/versions/CMXJetHits_v1.h',
            'body_includes': ["xAODTrigL1Calo/versions/CMXJetHits_v1.h"],
        })


        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTrigL1Calo',
            'link_libraries': ["xAODTrigL1Calo"],
        })

        for md in _enum_map.get(a.func.attr, []):
            s_update = s_update.MetaData(md)
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class CMXJetHits_v1:
    "A class"

    class Sources(Enum):
        REMOTE_MAIN = 0
        LOCAL_MAIN = 1
        TOTAL_MAIN = 2
        REMOTE_FORWARD = 4
        LOCAL_FORWARD = 5
        TOTAL_FORWARD = 6
        TOPO_CHECKSUM = 8
        TOPO_OCCUPANCY_MAP = 9
        TOPO_OCCUPANCY_COUNTS = 10
        MAX_SOURCE = 15


    def hitsVec0(self) -> func_adl_servicex_xaodr22.vector_int_.vector_int_:
        "A method"
        ...

    def hitsVec1(self) -> func_adl_servicex_xaodr22.vector_int_.vector_int_:
        "A method"
        ...

    def errorVec0(self) -> func_adl_servicex_xaodr22.vector_int_.vector_int_:
        "A method"
        ...

    def errorVec1(self) -> func_adl_servicex_xaodr22.vector_int_.vector_int_:
        "A method"
        ...

    def hits0(self) -> int:
        "A method"
        ...

    def hits1(self) -> int:
        "A method"
        ...

    def error0(self) -> int:
        "A method"
        ...

    def error1(self) -> int:
        "A method"
        ...

    def index(self) -> int:
        "A method"
        ...

    def usingPrivateStore(self) -> bool:
        "A method"
        ...

    def usingStandaloneStore(self) -> bool:
        "A method"
        ...

    def hasStore(self) -> bool:
        "A method"
        ...

    def hasNonConstStore(self) -> bool:
        "A method"
        ...

    def clearDecorations(self) -> bool:
        "A method"
        ...

    def trackIndices(self) -> bool:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('auxdataConst', s, a, param_1))
    @property
    def auxdataConst(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[func_adl_servicex_xaodr22.str.str]:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('isAvailable', s, a, param_1))
    @property
    def isAvailable(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[func_adl_servicex_xaodr22.str.str]:
        "A method"
        ...

==> func_adl_servicex_xaodr22-2.2.0.22.2.113-py3-none-any.whl: func_adl_servicex_xaodr22/xAOD/cmxjethits_v1.py <==
from __future__ import annotations
import ast
from typing import Tuple, TypeVar, Iterable
from func_adl import ObjectStream, func_adl_callback, func_adl_parameterized_call
from enum import Enum
import func_adl_servicex_xaodr22

_method_map = {
    'crate': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'crate',
        'return_type': 'uint8_t',
    },
    'sourceComponent': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'sourceComponent',
        'return_type': 'uint8_t',
    },
    'peak': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'peak',
        'return_type': 'uint8_t',
    },
    'hitsVec0': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'hitsVec0',
        'return_type_element': 'unsigned short',
        'return_type_collection': 'const vector<unsigned int>',
    },
    'hitsVec1': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'hitsVec1',
        'return_type_element': 'unsigned short',
        'return_type_collection': 'const vector<unsigned int>',
    },
    'errorVec0': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'errorVec0',
        'return_type_element': 'unsigned short',
        'return_type_collection': 'const vector<unsigned int>',
    },
    'errorVec1': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'errorVec1',
        'return_type_element': 'unsigned short',
        'return_type_collection': 'const vector<unsigned int>',
    },
    'hits0': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'hits0',
        'return_type': 'unsigned int',
    },
    'hits1': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'hits1',
        'return_type': 'unsigned int',
    },
    'error0': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'error0',
        'return_type': 'unsigned int',
    },
    'error1': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'error1',
        'return_type': 'unsigned int',
    },
    'index': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'index',
        'return_type': 'unsigned int',
    },
    'usingPrivateStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'usingPrivateStore',
        'return_type': 'bool',
    },
    'usingStandaloneStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'usingStandaloneStore',
        'return_type': 'bool',
    },
    'hasStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'hasStore',
        'return_type': 'bool',
    },
    'hasNonConstStore': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'hasNonConstStore',
        'return_type': 'bool',
    },
    'clearDecorations': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'clearDecorations',
        'return_type': 'bool',
    },
    'trackIndices': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'trackIndices',
        'return_type': 'bool',
    },
    'auxdataConst': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'auxdataConst',
        'return_type': 'U',
    },
    'isAvailable': {
        'metadata_type': 'add_method_type_info',
        'type_string': 'xAOD::CMXJetHits_v1',
        'method_name': 'isAvailable',
        'return_type': 'bool',
    },
}

_enum_map = {      
}

T = TypeVar('T')


def _add_method_metadata(s: ObjectStream[T], a: ast.Call) -> Tuple[ObjectStream[T], ast.Call]:
    '''Add metadata for a collection to the func_adl stream if we know about it
    '''
    assert isinstance(a.func, ast.Attribute)
    if a.func.attr in _method_map:
        s_update = s.MetaData(_method_map[a.func.attr])

        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTrigL1Calo/versions/CMXJetHits_v1.h',
            'body_includes': ["xAODTrigL1Calo/versions/CMXJetHits_v1.h"],
        })


        s_update = s_update.MetaData({
            'metadata_type': 'inject_code',
            'name': 'xAODTrigL1Calo',
            'link_libraries': ["xAODTrigL1Calo"],
        })

        for md in _enum_map.get(a.func.attr, []):
            s_update = s_update.MetaData(md)
        return s_update, a
    else:
        return s, a


@func_adl_callback(_add_method_metadata)
class CMXJetHits_v1:
    "A class"

    class Sources(Enum):
        REMOTE_MAIN = 0
        LOCAL_MAIN = 1
        TOTAL_MAIN = 2
        REMOTE_FORWARD = 4
        LOCAL_FORWARD = 5
        TOTAL_FORWARD = 6
        TOPO_CHECKSUM = 8
        TOPO_OCCUPANCY_MAP = 9
        TOPO_OCCUPANCY_COUNTS = 10
        MAX_SOURCE = 15


    def crate(self) -> int:
        "A method"
        ...

    def sourceComponent(self) -> int:
        "A method"
        ...

    def peak(self) -> int:
        "A method"
        ...

    def hitsVec0(self) -> func_adl_servicex_xaodr22.vector_int_.vector_int_:
        "A method"
        ...

    def hitsVec1(self) -> func_adl_servicex_xaodr22.vector_int_.vector_int_:
        "A method"
        ...

    def errorVec0(self) -> func_adl_servicex_xaodr22.vector_int_.vector_int_:
        "A method"
        ...

    def errorVec1(self) -> func_adl_servicex_xaodr22.vector_int_.vector_int_:
        "A method"
        ...

    def hits0(self) -> int:
        "A method"
        ...

    def hits1(self) -> int:
        "A method"
        ...

    def error0(self) -> int:
        "A method"
        ...

    def error1(self) -> int:
        "A method"
        ...

    def index(self) -> int:
        "A method"
        ...

    def usingPrivateStore(self) -> bool:
        "A method"
        ...

    def usingStandaloneStore(self) -> bool:
        "A method"
        ...

    def hasStore(self) -> bool:
        "A method"
        ...

    def hasNonConstStore(self) -> bool:
        "A method"
        ...

    def clearDecorations(self) -> bool:
        "A method"
        ...

    def trackIndices(self) -> bool:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('auxdataConst', s, a, param_1))
    @property
    def auxdataConst(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[func_adl_servicex_xaodr22.str.str]:
        "A method"
        ...

    @func_adl_parameterized_call(lambda s, a, param_1: func_adl_servicex_xaodr22.type_support.cpp_generic_1arg_callback('isAvailable', s, a, param_1))
    @property
    def isAvailable(self) -> func_adl_servicex_xaodr22.type_support.index_type_forwarder[func_adl_servicex_xaodr22.str.str]:
        "A method"
        ...
